"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginOptionsSchema = exports.createSchemaCustomization = exports.sourceNodes = void 0;
const fetch_pages_1 = require("./lib/fetch-pages");
const node_1 = require("./lib/node");
const sourceNodes = async ({ actions, createContentDigest, createNodeId, reporter }, { projectName, ...fetchPagesOptions }) => {
    const { createNode } = actions;
    const pagesResponse = await fetch_pages_1.fetchPages(projectName, fetchPagesOptions);
    if (pagesResponse instanceof Error) {
        reporter.panic(pagesResponse);
        return;
    }
    const buildNode = node_1.Node({ createContentDigest, createNodeId });
    for (const page of pagesResponse.pages) {
        const node = buildNode(page);
        createNode(node);
    }
    return;
};
exports.sourceNodes = sourceNodes;
const createSchemaCustomization = ({ actions: { createTypes }, schema, }) => {
    const typedefs = [
        schema.buildObjectType({
            name: `ScrapboxPage`,
            interfaces: [`Node`],
            fields: {
                accessed: "Int!",
                commitId: "String!",
                created: "Int!",
                descriptions: "[String!]!",
                image: "String",
                linked: "Int!",
                pageRank: "Int!",
                pin: "String!",
                snapshotCreated: "Int!",
                title: "String!",
                updated: "Int!",
                // user: "ScrapboxUser!",
                views: "Int!",
            },
        }),
    ];
    createTypes(typedefs);
};
exports.createSchemaCustomization = createSchemaCustomization;
const pluginOptionsSchema = ({ Joi, }) => {
    return Joi.object({
        projectName: Joi.string()
            .required()
            .description(`The project name following https://scrapbox.io/`),
        skip: Joi.number().description(`Number of pages to skip fetching`),
        limit: Joi.number().description(`Maximum number of pages to fetch`),
    });
};
exports.pluginOptionsSchema = pluginOptionsSchema;
